import { world, system, ItemComponentTypes } from "@minecraft/server";

const magnets = [
    "bey:default_magnet",
    "bey:golden_magnet",
    "bey:diamond_magnet",
    "bey:netherite_magnet"
];

system.runInterval(() => {
    world.getAllPlayers().forEach(player => {
        const inventory = player.getComponent("inventory").container;
        const invSize = inventory.size;

        for (let i = 0; i < invSize; i++) {
            const itemSlot = inventory.getSlot(i);

            if (itemSlot && itemSlot.hasItem()) {
                if (magnets.includes(itemSlot.typeId)) {
                    itemSlot.setLore(["§r§l§4- Interact §fTo Pull Items"]);
                }
            }
        }
    });
});


world.afterEvents.itemUse.subscribe((event) => {
    const itemStack = event.itemStack;
    const player = event.source;
    const playerLoc = player.location;

    if (magnets.includes(itemStack.typeId)) {
        player.playSound("hit.anvil");
        player.playSound("random.anvil_land");

        const durability = itemStack.getComponent(ItemComponentTypes.Durability);
        if (durability.damage === durability.maxDurability) {
            player.playSound('random.break');
            player.getComponent('equippable').setEquipment('Mainhand', undefined);
        } else {
            durability.damage++;
            player.getComponent('equippable').setEquipment('Mainhand', itemStack);
        }

        const magnetIndex = magnets.indexOf(itemStack.typeId);
        const maxDistance = 5 + magnetIndex * 3;

        player.dimension.getEntities({ location: playerLoc, maxDistance }).forEach(entity => {
            entity.dimension.spawnParticle("minecraft:llama_spit_smoke", entity.location);
            if (entity.typeId === "minecraft:items") {
                entity.teleport(playerLoc);
            }
        });
    }
});
